package com.pyvio.acquirer.sdk.dto.req;

import com.pyvio.acquirer.sdk.dto.req.inner.BillingInfoDTO;
import com.pyvio.acquirer.sdk.dto.req.inner.CustomerInfoDTO;
import com.pyvio.acquirer.sdk.dto.req.inner.GoodsInfoDTO;
import com.pyvio.acquirer.sdk.dto.req.inner.ShippingInfoDTO;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@Builder
@AllArgsConstructor
@NoArgsConstructor
@Data
public class CheckoutReqDTO implements Serializable {

    @Serial
    private static final long serialVersionUID = 6625586190363498478L;
    /**
     * website ID
     */
    private String websiteId;
    /**
     * unique transaction ID of merchant
     */
    private String transactionId;
    /**
     * payment type One Of SALE, AUTH
     */
    private String paymentType;
    /**
     * please use ISO4217 currency code eg. USD, CNY, CNY
     */
    private String currency;
    /**
     * please pass in the smallest unit of ISO4217 currency code.
     * eg. USD-1.32,KWD-1.333
     */
    private BigDecimal amount;
    /**
     * is the transaction specified to force 3DS(Y/N) default:N
     */
    private String threeDSecure;
    /**
     * merchant pay time, pattern:yyyy-MM-dd HH:mm:ss
     */
    private String merchantPayTime;
    /**
     * merchant customer id
     */
    private String customerId;
    /**
     * the expiration time of this transaction,
     * and is based on the pyvio system time, unit:minute
     */
    private String expiredTerm;
    /**
     * remark
     */
    private String remark;
    /**
     * merchant customized asynchronous notify url
     */
    private String notifyUrl;
    /**
     * merchant customized cashier redirect url
     */
    private String redirectUrl;
    /**
     * merchant customized cashier cancel url
     */
    private String cancelUrl;
    /**
     * billing info
     */
    private BillingInfoDTO billingInfo;
    /**
     * shipping info
     */
    private ShippingInfoDTO shippingInfo;
    /**
     * customer info
     */
    private CustomerInfoDTO customerInfo;
    /**
     * goods info
     */
    private List<GoodsInfoDTO> goodsInfo;

}