package com.pyvio.acquirer.sdk.dto.req;

import com.pyvio.acquirer.sdk.dto.req.inner.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * payment request parameter
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class PaymentPayReqDTO implements Serializable {

    @Serial
    private static final long serialVersionUID = -1721911022803091055L;
    /**
     * website ID
     */
    private String websiteId;
    /**
     * unique transaction ID of merchant
     */
    private String transactionId;
    /**
     * payment type One Of SALE, AUTH
     */
    private String paymentType;
    /**
     * specify international credit cards such as Visa and MasterCard,
     * or specify local payment methods such as GiroPay
     */
    private String paymentBrand;
    /**
     * payment method One Of CARD, APM
     */
    private String paymentMethod;
    /**
     * please use ISO4217 currency code eg. USD, CNY, CNY
     */
    private String currency;
    /**
     * please pass in the smallest unit of ISO4217 currency code.
     * eg. USD-1.32,KWD-1.333
     */
    private BigDecimal amount;
    /**
     * is the transaction specified to force 3DS(Y/N) default:N
     */
    private String threeDSecure;
    /**
     * merchant pay time, pattern:yyyy-MM-dd HH:mm:ss
     */
    private String merchantPayTime;
    /**
     * merchant member ID, for express payment option
     */
    private String customerId;
    /**
     * remark
     */
    private String remark;
    /**
     * card number
     */
    private String cardNumber;
    /**
     * the first name of cardHolder
     */
    private String cardHolderFirstName;
    /**
     * the last name of cardHolder
     */
    private String cardHolderLastName;
    /**
     * the month of expiration date，eg. 05
     */
    private String cardExpireMonth;
    /**
     * the year of expiration date，eg. 23
     */
    private String cardExpireYear;
    /**
     * credit card cvv, the cvv character length of Visa/MasterCard/JCB/Discover is three digits，
     * the CVV character length of American Express is four digits
     */
    private String cardCvv;
    /**
     * paymentBrand support country, country isoa2 code, only needed APM
     */
    private String tradeCountry;
    /**
     * 3ds redirect url
     */
    private String shopperResultUrl;
    /**
     * merchant customized asynchronous notify url
     */
    private String notifyUrl;
    /**
     * APM specialized assign parameters, json pattern
     */
    private String apmAssignData;
    /**
     * billing info
     */
    private BillingInfoDTO billingInfo;
    /**
     * shipping info
     */
    private ShippingInfoDTO shippingInfo;
    /**
     * terminal info
     */
    private TerminalInfoDTO terminalInfo;
    /**
     * customer info
     */
    private CustomerInfoDTO customerInfo;
    /**
     * goods info
     */
    private List<GoodsInfoDTO> goodsInfo;
    /**
     * risk info
     */
    private RiskInfoDTO riskInfo;

}
