package com.pyvio.acquirer.sdk.dto.res;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * payment response parameter
 */
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Data
public class PaymentOrderResDTO implements Serializable {

    @Serial
    private static final long serialVersionUID = 7872714302120864962L;
    /**
     * website ID
     */
    private String websiteId;
    /**
     * payment order ID returned from pyvio
     */
    private String paymentId;
    /**
     * unique transaction ID of merchant
     */
    private String transactionId;
    /**
     * transaction status, One Of SUCCESS, FAILED, PENDING
     */
    private String status;
    /**
     * refer to the Response Code
     */
    private String returnCode;
    /**
     * message of transaction result
     */
    private String returnMessage;
    /**
     * when payment result, One Of SALE, AUTH.
     * when query result, One Of SALE, AUTH, CAPTURE, VOID, REFUND
     */
    private String paymentAction;
    /**
     * transaction amount
     */
    private BigDecimal amount;
    /**
     * transaction currency
     */
    private String currency;
    /**
     * transaction time, pattern:yyyyMMddHHmmss
     */
    private String transactionTime;

    /**
     * the verification url of 3DS, only return with payment
     */
    private String acsUrl;
    /**
     * 3ds url jump request method, GET or POST, only return with payment
     */
    private String requestMethod;
    /**
     * 3ds validation parameter set, only return with payment
     */
    private String threeDUnionParams;
    /**
     * the url of payment redirect url, only return with payment
     */
    private String paymentRedirectUrl;
    /**
     * payment redirect request method, GET or POST, only return with payment
     */
    private String paymentRedirectRequestMethod;
    /**
     * payment redirect parameter set, only return with payment
     */
    private String paymentRedirectParams;
    /**
     * Electronic Commerce Indicator, only return with payment
     */
    private String eci;
}
