package com.pyvio.acquirer.sdk.util;

import okhttp3.ConnectionPool;
import okhttp3.OkHttpClient;

import java.util.concurrent.TimeUnit;

public class OkHttpClientSingleton {

    private OkHttpClientSingleton(){
    }

    private static volatile OkHttpClient clientInstance;

    public static OkHttpClient getClientInstance() {
        if (clientInstance == null) {
            synchronized (OkHttpClientSingleton.class){
                if (clientInstance == null){
                    clientInstance = new OkHttpClient.Builder()
                            .connectTimeout(5000, TimeUnit.MILLISECONDS)
                            .writeTimeout(30000, TimeUnit.MILLISECONDS)
                            .readTimeout(30000, TimeUnit.MILLISECONDS)
                            .connectionPool(new ConnectionPool(10,5, TimeUnit.MILLISECONDS))
                            .retryOnConnectionFailure(true)
                            .build();
                }
            }
        }
        return clientInstance;
    }
}